<?php
/**
 * Plugin Name: Easy to Manage Vendor.
 * Plugin URI: 
 * Description: With this plugin, the system admin of WhatsApp will be able to easily communicate with the vendor and the vendor in WhatsApp will also be able to communicate with the system admin easily.
 * Version:     1.0.2
 * Author:      Naeem khan
 * Author URI:  https://profiles.wordpress.org/naeemkhan25/
 * Text Domain:  EMV
 * Domain Path: /languages/
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 */

// don't call the file directly
if ( ! defined( 'ABSPATH' ) ) {
	wp_die( __( 'You can\'t access this page', 'EMV' ) );
}

/** define constants */
if ( ! defined( 'EMV_VERSION' ) ) {
	define( 'EMV_VERSION', '1.0.2' );
	define( 'EMV_PATH',plugin_dir_path(__FILE__) );
	define( 'EMV_INCLUDES', EMV_PATH . 'includes' );
    define( 'EMV_URL', plugin_dir_url(__FILE__));
    define( 'EMV_ASSETS', EMV_URL . '/assets');
    define( 'EMV_FILE', __FILE__ );
  
}
 if ( ! class_exists( 'EMV' ) ) {
    final class EMV {
        /**
        * @var use define php version
        */
        private static $min_php = '5.6.0';

        private  function __construct() {
          register_activation_hook( EMV_FILE, [ $this, 'Initial_activation' ] );
          if ( self::check_dependent_true() ) {
            add_action('plugins_loaded', [ $this, 'load_plugin' ] );
            add_action( 'activated_plugin', [ $this, 'activation_redirect' ] );
            add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), [ $this, 'plugin_action_links' ] );
          }
        }
        /**
		 * EMV plugin action links
		 * plugin_action_links method use for show Setting in plugin.php
		 *
		 * @param array $links link setting page.
		 *
		 * @return array
		 */
		public function plugin_action_links( $links ) {
			$plugin_link1 = [
				'<a href="' . admin_url( 'admin.php?page=emv_settings' ) . '">' . __( 'Settings', 'EMV' ) . '</a>'
			];
			$plugin_links = array_merge( $links, $plugin_link1 );
			return $plugin_links;
		}
        /**
         * Load easy to manage vendor plugin
         *
         * @version 1.0.0
         */
        public function load_plugin() {
            #activation hook
            $this->load_plugin_textdomain();
            self::include_files();
            add_action( 'wp_enqueue_scripts', array( $this, 'frontend_scripts' ));
            add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue' ) );    
        }
        /**
		 * When plugin active redirect to setting page
		 *
		 * @param array $plugin comment about this variable.
		 *
		 * @version 1.0.0
		 */
		public function activation_redirect( $plugin ) {
			$plugin_file = plugin_basename( __FILE__ );
			if ( $plugin_file == $plugin ) {
				wp_safe_redirect( admin_url( 'admin.php?page=emv_settings' ) );
				exit;
			}
		}
        /**
         * Check all dependencies
         * @return boolean
         * @since  1.0.0
         */
        public static function check_dependent_true(){
            
            if ( self::check_environment() && self::is_woocommerce_activated() && self::check_multivendor_active() ) {
                return true;
            }
            return false;
        }
        /**
         * Check multivendor active.
         *
         * @version 1.0.0
         */
        private static function check_multivendor_active() {
            $active_value = true;
            include_once (ABSPATH . 'wp-admin/includes/plugin.php');

            if ( self::check_dokan() || self::check_wcfm() ) {
                $active_value = true;
            } else {
                $active_value    = false;
                $in_active_notice = sprintf(
                    __('%s Easy To Manage Vendor is inactive.%sThe 
                    %sDokan multi-vendor%s
                    OR %sWCFM Marketplace%s
                    must be active for the %sEasy To Manage Vendor %sto work . Please
                    %sinstall & activate dokan multivendor%s
                    OR
                    %sinstall & activate WCFM Marketplace%s', 'EMV'
                    ) , '<strong>', '</strong>','<a target="_blank" href="https://wordpress.org/plugins/dokan-lite/">', '</a>','<a target="_blank" href="https://wordpress.org/plugins/wc-multivendor-marketplace/">', '</a>', '<strong>', '</strong>', '<a href="' . admin_url('plugins.php') . '">', '&nbsp;&raquo;</a>','<a href="' . admin_url('plugins.php') . '">', '&nbsp;&raquo;</a>');
            }

            /** Add notice and deactivate the plugin if woocommerce inactive */
            if ( ! $active_value ) {
                add_action(
                    'admin_notices', function () use ( $in_active_notice ) { ?>
                    <div class="notice notice-warning is-dismissible">
                        <p><?php printf($in_active_notice); ?></p>
                    </div>
                    <?php
                }
                );
                return $active_value;
             } else {
                return $active_value;
            }
        }

        /**
         * Check dokan is active
         *
         * @version 1.0.0
         */
        private static function check_dokan(){
            $pluginList   = get_option( 'active_plugins' );
			$dokan_active = 'dokan-lite/dokan.php';
            if ( in_array( $dokan_active, $pluginList ) ) {
                return true;
            }
            return false;
        }
        /**
         * Check Wcfm is active
         *
         * @version 1.0.0
         */
        private static function check_wcfm(){
            $pluginList = get_option( 'active_plugins' );
			$wcfm       = 'wc-frontend-manager/wc_frontend_manager.php';
            if ( in_array( $wcfm, $pluginList ) ) {
                return true;
            }
            return false;
        }
        /**
         * Some important task for run easy to manage vendor plugin 
         */
        public function Initial_activation() {
            $this->create_default_data();
        }
        /**
         * Ensure theme and server variable compatibility
         *
         * @return boolean
         * @since  1.0.0
         * @access private
         */
        private static function check_environment() {

            $return = true;
            /** Check the PHP version compatibility */
            if ( version_compare( PHP_VERSION, self::$min_php, '<=' ) ) {
                $return = false;

                $notice = sprintf( esc_html__( 'Unsupported PHP version Min required PHP Version: "%s"', 'EMV' ), self::$min_php );
            }

            /** Add notice and deactivate the plugin if the environment is not compatible */
            if ( ! $return ) {
                add_action(
                    'admin_notices', function () use ( $notice ) { ?>
                    <div class="notice is-dismissible notice-error">
                        <p><?php printf($notice); ?></p>
                    </div>
                    <?php
                }
                );
                return $return;
            } else {
                return $return;
            }
        }

        /**
         * Check wooCommerce active or not .
         * @return bool
         */
        private static function is_woocommerce_activated() {
            $active_value = true;
            include_once (ABSPATH . 'wp-admin/includes/plugin.php');

            if ( is_plugin_active('woocommerce/woocommerce.php') ) {
                $active_value = true;
            } elseif ( is_plugin_active_for_network('woocommerce/woocommerce.php') ) {
                $active_value = true;
            } else {
                $active_value    = false;
               $in_active_notice = sprintf(__('%s Easy Chat With Vendor  is inactive.%s The %sWooCommerce plugin%s must be active for the %sEasy Chat With Vendor %s to work . Please %sinstall & activate WooCommerce%s', 'EMV') , '<strong>', '</strong>', '<a target="_blank" href="http://wordpress.org/extend/plugins/woocommerce/">', '</a>', '<strong>', '</strong>', '<a href="' . admin_url('plugins.php') . '">', '&nbsp;&raquo;</a>');
            }

            /** Add notice and deactivate the plugin if woocommerce inactive */
            if ( ! $active_value ) {
                add_action(
                    'admin_notices', function () use ( $in_active_notice ) { ?>
                    <div class="notice notice-warning is-dismissible">
                        <p><?php printf($in_active_notice); ?></p>
                    </div>
                    <?php
                }
                );
                return $active_value;
             } else {
                return $active_value;
            }
        }
        /**
         * Load scripts use by conditionally
         *
         * @return boolean
         * @version 1.0.0
         */
        public function check_load_capabilities() {
            global $wp;
			$current_page = $wp->query_vars;
            $user_non_logged_id = is_user_logged_in();
            if ( array_key_exists('pagename', $current_page ) ) {
                if ( ( 'my-account' == $current_page['pagename'] && ! $user_non_logged_id ) || ( 'dashboard' == $current_page['pagename'] && $user_non_logged_id ) || ( 'store-manager' == $current_page['pagename'] && $user_non_logged_id ) ) {
                    return true;
                }
            }
            return false;
        }
        /**
         * EMV frontend enqueue Scripts
         * 
         * @return void
         * @version 1.0.0
         */
        public function frontend_scripts() {
            $check_load_capabilities = $this->check_load_capabilities();
            $fronted_default_country = get_option( 'emv_default_country_select', 'us' );
            $phone_number         = get_option( 'EMV_admin_phone_number');
            $check_api_active        = get_option( 'emv_enable_automatic_sms' , 0 );
            $check_seller_permission = get_option( 'emv_enable_vendor_automatic_sms', 0 );
            
            $vendor_chat_availity    = get_option( 'emv_disable_vendor_chat', 0 );
            // die($check_load_capabilities);
            if ( $check_load_capabilities ) {
                wp_enqueue_style('EMV_user_css', EMV_ASSETS . '/register/user.css');
                $check_already_enqueued = $this->check_script_is_already_load( 'jquery-blockui' );
				if ( ! $check_already_enqueued ) {
					wp_enqueue_script( 'jquery-blockui', EMV_ASSETS . '/register/jquery.blockUI.js', [ 'jquery' ], EMV_VERSION, false );
				}
                wp_enqueue_script('EMV_intlTellnput_js', EMV_ASSETS . '/register/intlTelInput.js', array('jquery') , EMV_VERSION, true);
                wp_localize_script( 'EMV_intlTellnput_js', 'EMV_default_country', [
					'default_country' => $fronted_default_country
				] );
                wp_enqueue_script('EMV_emv_js', EMV_ASSETS . '/register/emv.js', array('jquery') , EMV_VERSION, true);
                wp_localize_script('EMV_emv_js', 'EMV_localize_data', [
                    'plugin_Urls' => EMV_URL,
                    'emv_vendor_ajax_url'  => admin_url('admin-ajax.php'),
                    'emv_vendor_security'  => wp_create_nonce('emv_vendor_save'),
                    'emv_send_security'    => wp_create_nonce('emv_vendor_send_sms'),
                    'vendor_chat_availity' => $vendor_chat_availity,
                    'phone_number'         => $phone_number,
                    'api_active'           => $check_api_active,
                    'venodr_api_active'    => $check_seller_permission,
                    'availity_message'     => __( 'System admin is not ready to receive SMS. Please contact the system admin.', 'EMV' ),
                    'availity_message2'    => __( 'Admin is not interested in receiving SMS. Please contact the system admin.', 'EMV' )
                ] );
            }
        }
	    /**
		 * Check scripts already exist
		 *
		 * @param String $handle return current page.
		 *
		 * @param String $list list out scripts.
		 * @version 1.0.0
		 */
		public function check_script_is_already_load( $handle, $list = 'enqueued' ) {
			return wp_script_is( $handle, $list );
		}

        /** 
         * Emv admin scrripts
         * 
         * @version 1.0.0
         * @return void
        */
        public function admin_enqueue(){
            $screen = get_current_screen();
            $enable_edit_mode = get_option( 'emv_enable_edit_mode', 1 );
            $default_country  = get_option( 'emv_default_country_select', 'us' );
            wp_enqueue_style('EMV_setting_css', EMV_ASSETS.'/css/setting.css');
            wp_enqueue_script('EMV_setting_js', EMV_URL . '/assets/setting/setting.js', ['jquery', 'wp-element'] , EMV_VERSION, true);
            wp_localize_script('EMV_setting_js', 'EMV_setting_data',[
                'emv_ajax_url' => admin_url('admin-ajax.php'),
                'emv_rest_apiUrl' => home_url('/wp-json'),
                'emv_rest_nonce' => wp_create_nonce('wp_rest'),
                'emv_security' => wp_create_nonce('emv_setting_get_save')
            ]);
            if ( $screen->id == 'chat-with-vendor_page_emv_setting' || $screen->id == 'chat-with-vendor_page_emv_settings') {
                
                wp_enqueue_style('EMV_user_css', EMV_ASSETS . '/register/user.css');
                wp_enqueue_script('EMV_intlTellnput_js', EMV_ASSETS . '/register/intlTelInput.js', array('jquery') , EMV_VERSION, true);
                wp_localize_script( 'EMV_intlTellnput_js', 'EMV_default_country', [
					'default_country' => $default_country
				] );
                wp_enqueue_script('EMV_admin_js', EMV_ASSETS . '/js/admin.js', array('jquery') , EMV_VERSION, true);
                wp_localize_script('EMV_admin_js', 'EMV_isValid', 
                [
                    'plugin_Urls' => EMV_URL,
                    'ajax_url' => admin_url('admin-ajax.php'),
                    'security' => wp_create_nonce('emv_save_amdin_phone')
                ]);
            
            }
            if ( $screen->id == 'toplevel_page_esay-to-manage-vendor' ) {
                wp_enqueue_style('EMV_list_css', EMV_ASSETS . '/css/wp-list.css');
                wp_enqueue_script('EMV_vendor_list_js', EMV_ASSETS . '/js/vendor_list.js', array('jquery') , EMV_VERSION, true); 
                wp_localize_script('EMV_vendor_list_js', 'EMV_vendor_list', 
                array(
                    'ajax_url' => admin_url('admin-ajax.php'),
                    'security' => wp_create_nonce('emv_manual_sendSMS'),
                    'security2' => wp_create_nonce('emv_delete_transient'),
                    'security3' => wp_create_nonce( 'emv_automatic_sms' ),
                    'security4' => wp_create_nonce( 'emv_bulk_sms' ),
                    'edit_mode' => $enable_edit_mode
                    )
                );
            }
            
        }
        /**
         * Includes necessary file
         * 
         * @return void
         * @version 1.0.0
         */
        private static function include_files() {
            require_once EMV_INCLUDES . '/class-helper.php';
            require_once EMV_INCLUDES . '/admin/class-numbers-list.php';
            require_once EMV_INCLUDES . '/admin/numbers.php';
            require_once EMV_INCLUDES . '/admin/class-setting.php';
            require_once EMV_INCLUDES . '/admin/class-menu.php';
            require_once EMV_INCLUDES . '/class-register-rest.php';
            require_once EMV_INCLUDES . '/class-ajax.php';
            require_once EMV_INCLUDES . '/frontend/dokan/class-register.php';
            require_once EMV_INCLUDES . '/frontend/dokan/class-dokan-menu.php';
            require_once EMV_INCLUDES . '/frontend/WCFM/wcfm-menu.php';
            require_once EMV_INCLUDES . '/hook/class-hook.php';
            require_once EMV_INCLUDES . '/class-send-sms.php';
			require_once EMV_INCLUDES . '/class-send-vendor-sms.php';
        }
        
        /**
         * loaded plugin text domain for translation.
         * @return bool
         */
        public function load_plugin_textdomain() {
            $domain = 'EMV';
            $dir    = untrailingslashit(WP_LANG_DIR);
            $locale = apply_filters('plugin_locale', get_locale() , $domain);
            if ( $exists = load_textdomain($domain, $dir . '/plugins/' . $domain . '-' . $locale . '.mo')) {
                return $exists;
            } else {
                load_plugin_textdomain($domain, false, basename(dirname(__FILE__)) . '/languages/');
            }
        }

        /**
        * Create plugin settings default data
        * @since 1.0.0
        */
        public function create_default_data() {

            $version        = get_option ( 'EMV_version', '0' );
            $install_time   = get_option ( 'EMV_install_time', '' );
            $run_first_time = get_option ( 'emv_run_first_time', 0 );

            if ( $run_first_time == 0 ) {
                update_option( 'emv_run_first_time', 1 );
                update_option ( 'emv_message_subject', 'Initial conversation' );
                update_option ( 'emv_message_desc', 'Hello {vendorShopName}, how are you.' );
                update_option ( 'emv_enable_api_edit_mode', 1 );
                update_option ( 'emv_enable_edit_mode', 1 ); 
            }
            if ( empty( $version ) ) {
                update_option ( 'EMV_version', EMV_VERSION );
            }

            if ( ! empty( $install_time ) ) {
                $date_format = get_option( 'date_format' );
                $time_format = get_option( 'time_format' );
                update_option ( 'EMV_install_time', date( $date_format . ' ' . $time_format ) );
            }
            update_option ( 'EMV_active' , 1 );
            flush_rewrite_rules();
            
        }
        
        /**
        * initializes singleton instance.
        */
        public static function init() {
            static $instance = false;
            if ( ! $instance ) {
                $instance = new self();
            }
            return $instance;
        }
    }

    /**
    * kick-of the plugin
    */
    EMV::init();
   
 }