<?php
/**
 * Action Request Class
 */
if ( ! defined('ABSPATH') )
{
    exit;
}
if ( ! class_exists('EMV_Numbers') ) {

     class EMV_Numbers {
        /**
         * get Vendor info
         * @return array
         * @version 1.0.0
         */
        public function vendor_data() {
            $all_vendor = [];
            $args       = array(
                'roles'    => array( 'seller', 'wcfm_vendor '),
                'role__not_in' => ['administrator'],
                'orderby' => 'ID',
                'order'   => 'ASC',
                'fields'  => 'all',
            );
            $users = get_users( $args );  
             $i    = 0;
            foreach ( $users as $user ) {
                $all_vendor[$i]['id']           = $user->ID;
                $phoneNumber                 =  get_user_meta( $user->ID,'EMV_phone_number',true);
               
                if ( $phoneNumber ) {
                    $all_vendor[$i]['phone'] = $phoneNumber;
                } else {
                    $all_vendor[$i]['phone'] = __( 'Number not given', 'EMV' );
                }
                $get_user_status = get_user_meta( $user->ID, 'emv_user_sms_status', true );
                if ( $get_user_status ) {
                    $all_vendor[$i]['status'] = $get_user_status;
                } else {
                    $all_vendor[$i]['status'] = __('Unsend','EMV');
                }
                $all_vendor[$i]['vendor']      = $user->user_nicename;
                $all_vendor[$i]['current_msg'] = [
                    'message'  => get_user_meta( $user->ID, 'EMV_current_message', true ),
                    'awaiting' => get_transient( "message_count_$user->ID", 0 ),
                ];
                $all_vendor[$i]['register'] = $user->user_registered;
                $i++;
            }
          
           return $all_vendor;
        }
        
        /**
         * Search by list
         * @return boolean
         */
        function emv_vendor_search( $item ) : bool {   

            $whtsApp = (string) $item['phone'];
            $vendorName = (string) $item['vendor'];
           
            $request_value =(string) sanitize_text_field($_REQUEST['s']);
         
            if( stripos($whtsApp,$request_value) !== false ) {
                return true;
            }
            if( stripos($vendorName,$request_value) !== false ) {
                return true;
            }
            return false;

        }

        /**
         * Filter by Status
         * @return boolean
         * @version 1.0.0
         */
        function emv_filter_by_status( $item) : bool {
            $status        = $item['status'];
            $filter_status = sanitize_text_field($_REQUEST["emv_felter_s"]);

            if ( 'all' == $filter_status) {
                return true;
            } else {
                if ($status == $filter_status ) {
                    return true;
                }
            }
            return false;
        }
         /**
         * WP list Table call
         * @return void
         * @version 1.0.0
         */
        public function emv_numbers_list() {
            
            $table   = new EMV_numbers_list();

            $data    = $this->vendor_data();
    
            #order by vendor or phone number
            $orderBy = isset( $_REQUEST['orderby'] ) ? sanitize_text_field( $_REQUEST['orderby'] ) : '';
            $order = isset( $_REQUEST['order'] ) ? sanitize_text_field( $_REQUEST['order'] ) : '';
            if ('phone' == $orderBy ) {
                if ( 'asc'== $order ) {
                    usort($data,function ($item1,$item2) {
                        return $item1['phone'] <=> $item2['phone'];
                    });
                }else {
                    usort($data,function ($item1,$item2) {
                        return $item2['phone'] <=> $item1['phone'];
                    });
                }
            } else if ('vendor' == $orderBy ) {
                if ( 'asc'== $order ) {
                    usort($data,function ($item1,$item2) {
                        return $item1['vendor'] <=> $item2['vendor'];
                    });
                }else {
                    usort($data,function ($item1,$item2) {
                        return $item2['vendor'] <=> $item1['vendor'];
                    });
                }
            } else if ('register' == $orderBy ) {
                if ( 'asc'== $order ) {
                    usort($data,function ($item1,$item2) {
                        return $item1['register'] <=> $item2['register'];
                    });
                }else {
                    usort($data,function ($item1,$item2) {
                        return $item2['register'] <=> $item1['register'];
                    });
                }
            }
            # end order by vendor or phone number
            $filter_status = isset( $_REQUEST['emv_felter_s'] ) ? sanitize_text_field( $_REQUEST['emv_felter_s'] ):  "";
            #filter Status
            if ( isset( $filter_status ) && !empty( $filter_status ) ) {
                $data   = array_filter ($data,[$this,'emv_filter_by_status']);
            }
            #end Filter Status
            $search = isset( $_REQUEST['s'] ) ? sanitize_text_field( $_REQUEST['s'] ):"";
            #search by vendor or phone
            if ( isset( $search ) && ! empty( $search ) ) {
                $data = array_filter($data,array($this,'emv_vendor_search'));
            }
             #search by vendor or phone

            $table->set_data($data);
            $table->prepare_items();
            $this->_form_table($table);  
           
        }

        /**
         * Vendor list table form
         * @return void
         */
        function _form_table($table) {
            ?>
                <div class="wrap ">
                    <div class="emv_wrap_list"></div>
                    <div class="emv_main_layout">
                        <div class="emv_heading_numbers"><?php _e('All WhatsApp Numbers','EMV');?></div>
                            <div class='emv_list_numbers'>
                                <form method='GET' action="">                           
                                    <?php
                                        $paged = filter_input( INPUT_GET, 'paged', FILTER_SANITIZE_NUMBER_INT );
                                        printf( '<input type="hidden" name="paged" value="%d" />', $paged );
                                        $table->search_box("search","search_id_emv");
                                        $table->display();
                                        wp_nonce_field('emv_list_nonce','emv_list_nonce');
                                        ?>

                                    <input type="hidden" name="page" value="<?php echo esc_attr( $_REQUEST['page'] ); ?>">
                                </form>
                        </div>
                    </div>
                </div>
            <?php
        }

    }
}