<?php

if ( !defined('ABSPATH') ) {
    exit;
}

if ( ! class_exists('EMV_vendor_ajax') ) {
    /**
     * Emv all ajax call for save and get data
     * 
     * @return object
     * @version 1.0.0
     */
    class EMV_vendor_ajax {
        /**
         * Store emv helper object value
         * Public @var
         * 
         * @version 1.0.0
         */
        public $emv_helpers;
        /**
         * Calling method
         */
        function __construct(){
            $this->emv_helpers = new EMV_helper();
            add_action('wp_ajax_emv_manual_sendSMS',[ $this,'send_manual_sms']);
            add_action('wp_ajax_emv_bulk_sms',[ $this,'emv_bulk_sms']);
            add_action('wp_ajax_emv_save_amdin_phone',[ $this,'save_phone_number']);
            add_action('wp_ajax_emv_setting_get_save',[$this,'get_setting_data']);
            add_action('wp_ajax_emv_custom_css', [ $this, 'emv_custom_css' ] ) ;
            add_action('wp_ajax_emv_vendor_save', [ $this, 'emv_save_phone_number'] ); 
            add_action('wp_ajax_emv_vendor_send_sms', [ $this, 'send_vendor_sms' ] );
            add_action( 'wp_ajax_emv_delete_transient', [ $this, 'emv_delete_transient'] );
            add_action( 'wp_ajax_emv_api_popup_sms', [ $this, 'emv_api_popup_sms'] );
        }
        /**
         * Send popup SMS
         *
         * @version 1.0.0
         */
        public function emv_api_popup_sms() {
            if ( isset( $_POST ) ) {
                $security  = sanitize_text_field( $_POST['security'] );
                $vendor_id = sanitize_text_field( $_POST['vendorIDS'] );
                $subject   = sanitize_text_field( $_POST['subject'] );
                $message   = sanitize_text_field( $_POST['message'] );
                $access         = $this->emv_helpers->emv_check_security( $security, 'emv_automatic_sms', false );
                if ( ! $access ) {
                    return false;
                }
                $blogname = get_bloginfo('name');
                $message  = "From : $blogname\r\nSubject : $subject \r\nMessage: $message ";
                $call_api = new EMV_Send_SMS( $vendor_id, $message );
                $send     = $call_api->send_phone_sms();
                if ( $send ) {
                    wp_send_json( [
                        'message' => true
                    ] );
                } else {
                    wp_send_json( [
                        'message' => false
                    ] );
                }
            }
            die();
        }
        /**
         * Delete Transient
         *
         * @version 1.0.0
         */
        public function emv_delete_transient() {
            if ( isset($_POST ) ) {
                $security       = sanitize_text_field( $_POST['security'] );
                $vendor_id      = sanitize_text_field( $_POST['vendor_id'] );
                $access         = $this->emv_helpers->emv_check_security( $security, 'emv_delete_transient', false );
                if ( ! $access ) {
                    return false;
                }
                delete_transient( "message_count_$vendor_id" );
            }
            die();
        }
        /**
         * Send vendor SMS
         *
         * @version 1.0.0
         */
        public function send_vendor_sms() {
            if ( isset($_POST ) ) {
                $security       = sanitize_text_field( $_POST['security'] );
                $phone_number   = sanitize_text_field( $_POST['admin_phone'] );
                $message        = sanitize_text_field( $_POST['message'] );
                $vendor_id      = sanitize_text_field( $_POST['vendor_id'] );
                $access         = $this->emv_helpers->emv_check_security( $security, 'emv_vendor_send_sms', true );
                if ( ! $access ) {
                    return false;
                }
                update_user_meta( $vendor_id, 'EMV_current_message', $message );
                $vendor_send_count = get_transient( "message_count_$vendor_id" ) ? get_transient( "message_count_$vendor_id" ) : 0;
                ++$vendor_send_count;
                set_transient( "message_count_$vendor_id", $vendor_send_count, 0 );
                $check_api_active        = get_option( 'emv_enable_automatic_sms' , 0 );
                $check_seller_permission = get_option( 'emv_enable_vendor_automatic_sms', 0 );
                if ( $check_api_active == '1' &&  $check_seller_permission == '1' ) {
                    $userInfo     = get_userdata( $vendor_id );
                    $shop_name    = $userInfo->user_nicename;
                    $display_name = $userInfo->display_name;
                    $message      = "Name : $display_name\r\nShop Name : $shop_name \r\nMessage: $message ";
                    $Call_object  = new EMV_Vendor_Send_SMS( $phone_number, $message );
                    $send = $Call_object->send_phone_sms();
                    if ( $send ) {
                        wp_send_json( [
                            'message' => true
                        ] );
                    } else {
                        wp_send_json( [
                            'message' => false
                        ] );
                    }
                } else {
                    wp_send_json( [
                        'message' => true
                    ] );
                }
            }
            die();
        }
        /**
         * Save vendor phone number.
         * 
         * @version 1.0.0
         */
        public function emv_save_phone_number() {
            if ( isset($_POST ) ) {
                $security       = sanitize_text_field( $_POST['security'] );
                $phone_number   = sanitize_text_field( $_POST['emv_phone'] );
			    $str_trim_phone = trim( $phone_number, '' );
			    $vendor_number   = str_replace( '-', '', $str_trim_phone );
                $vendor_id = sanitize_text_field( $_POST['vendor_id'] );
                $access = $this->emv_helpers->emv_check_security( $security, 'emv_vendor_save', true );
                if ( ! $access ) {
                    return false;
                }
                update_user_meta( $vendor_id, 'EMV_phone_number', $vendor_number );
            }
            die();
        }
        /**
         * Save emv custom css value
         * 
         * @return json
         * @version 1.0.0
         */
        public function emv_custom_css() {
            if ( isset($_POST ) ) {
                $security = sanitize_text_field( $_POST['security'] );
                $custom_css = sanitize_text_field( $_POST['custom_css']);
                $access = $this->emv_helpers->emv_check_security( $security, 'emv_setting_get_save' );
                if ( $access == false ) {
                    return false;
                }
                update_option( 'emv_custom_css', $custom_css );  
            }
            die();

        }

        /**
         * get all setting data from
         * @return wp_json() 
         */
        public function get_setting_data () {

            if ( isset( $_POST ) ) {

                $security        =  sanitize_text_field( $_POST['security'] ); 
                $access = $this->emv_helpers->emv_check_security( $security, 'emv_setting_get_save' );
                if ( $access == false ) {
                    return false;
                }

                $gateway = $this->gat_gateway();
                $config  = $this->gat_configaration();
                $message = $this->get_message();
                $emv_css = $this->get_custom_css();
                
                wp_send_json(
                    array ( 
                    'gateway'       => $gateway, 
                    'configaration' => $config, 
                    'message'       => $message, 
                    'custom_css'    => $emv_css
                    )
                 );

            }
            die();
        }
        /**
         * Get custom css values
         * 
         * @return array
         * @version 1.0.0
         */
        public function get_custom_css() {
            $custom_css = [];
            $custom_css['custom_css'] = $this->emv_helpers->get_option_values( 'custom_css','.emv_register_form_wrap { } .emv_form_css { } .emv_dokan_dashboard_wrap { }' );
            return $custom_css;
        }

        /**
         * get gateway option all option values
         * @return array
         */
        public function gat_gateway () {
            $gateway = [];
            $gateway['enable_automatic_sms']         = $this->emv_helpers->get_option_values( 'enable_automatic_sms', 0 );
            $gateway['enable_vendor_automatic_sms']  = $this->emv_helpers->get_option_values( 'enable_vendor_automatic_sms', 0 );
            $gateway['select_api']                   = $this->get_api();
            $gateway['ultramsg']                     = $this->get_ultramsg();
            $gateway['twilio']                       = $this->get_twilio();
            return $gateway;

        }

        /**
         * get Select API value
         * @return mixed
         */
        public function get_api () {
            $selected_api = $this->emv_helpers->get_option_values( 'select_api', 1, true);
            return $selected_api;
        } 

        /**
         * get ultramsg api auth token and instance id
         * @return array
         */
        public function get_ultramsg () {
            $ultramsg = [];
            $ultramsg['instance_id'] = $this->emv_helpers->get_option_values('ultramsg_instance_id');
            $ultramsg['auth_token']  = $this->emv_helpers->get_option_values('ultramsg_auth_token');
            return $ultramsg;
        }
         /**
         * get twilio api auth token and sender number and account sid
         * @return array
         */
        public function get_twilio () {
            $twilio = [];
            $twilio['account_sid']    = $this->emv_helpers->get_option_values('twilio_account_sid');
            $twilio['auth_token']     = $this->emv_helpers->get_option_values('twilio_auth_token');
            $twilio['sender_number']  = $this->emv_helpers->get_option_values('twilio_sender_number');
            return $twilio;
        }

        /**
         * get all configaration setting data
         */
        public function gat_configaration () {
            $config = [];
            $config['default_country_select']         = $this->emv_helpers->get_option_values( 'default_country_select', 'us' );
            $config['disable_vendor_chat']            = $this->emv_helpers->get_option_values( 'disable_vendor_chat', 0 );
            $config['hide_phone_number']           = $this->emv_helpers->get_option_values( 'hide_phone_number', 0 );
            $config['enable_edit_mode']               = $this->emv_helpers->get_option_values( 'enable_edit_mode', 0 );
            $config['disable_vendor_number_Forcibly'] = $this->emv_helpers->get_option_values( 'disable_vendor_number_Forcibly', 0 );
            $config['enable_api_edit_mode']           = $this->emv_helpers->get_option_values( 'enable_api_edit_mode', 0 );
            return $config;
        }
        /** 
         * Get message default value 
         */
        public function get_message () {
            $message = [];
            $message['message_subject'] = $this->emv_helpers->get_option_values( 'message_subject' );
            $message['message_desc'] = $this->emv_helpers->get_option_values( 'message_desc' );
            return $message;
        }
        /**
         * Save Admin phone number
         * 
         * @version 1.0.0
         * @return void
         */
        public function save_phone_number () {
            if( isset($_POST)) {
                $security        =  sanitize_text_field( $_POST['security'] );
                $phones_number   = sanitize_text_field( $_POST['phone'] );
                $access          = $this->emv_helpers->emv_check_security( $security, 'emv_save_amdin_phone',false );
                
                if ( $access == false ) {
                    return false;
                }
                update_option( 'EMV_admin_phone_number', $phones_number );
            }
            die();
        }

        public function send_manual_sms() {
            
            if  ( isset( $_POST) ) {

                $security  =  sanitize_text_field( $_POST['security'] );
                $vendor_id = sanitize_text_field($_POST['emv_data_id']);
                $access    = $this->emv_helpers->emv_check_security( $security, 'emv_manual_sendSMS' );
                
                if ( $access == false ) {
                    return false;
                }
                $userInfo      = get_userdata( $vendor_id );
                $shop_name     = $userInfo->user_nicename;
                $from_name     = get_bloginfo( 'name' );
                $emv_sub       = get_option ( 'emv_message_subject' );
                $emv_sub1      = str_replace( '{vendorShopName}', $shop_name, $emv_sub );
                $emv_message   = get_option ( 'emv_message_desc' );
                $emv_message1  = str_replace( '{vendorShopName}', $shop_name, $emv_message );
                $message       = "From : $from_name\r\nSubject : $emv_sub1 \r\nMessage: $emv_message1 ";
                $call_api      = new EMV_Send_SMS( $vendor_id, $message );
                $send          = $call_api->send_phone_sms();
                if ( $send ) {
                    wp_send_json( [
                        'message' => true
                    ] );
                } else {
                    wp_send_json( [
                        'message' => false
                    ] );
                }
            }
           die;
        }

        /**
         * Send Bulk SMS
         */
        public function emv_bulk_sms() {
            
            if  ( isset( $_POST) ) {
                $security   =  sanitize_text_field( $_POST['security'] );
                $vendor_ids = isset( $_POST['vendorIDS'] ) ? $this->emv_helpers->recursive_sanitize_text_field( $_POST['vendorIDS'] ) : [];

                $access     = $this->emv_helpers->emv_check_security( $security, 'emv_bulk_sms' );

                if ( $access == false ) {
                    return false;
                }
                $send_count = 0;
                $failed_count = 0;
                if ( ! empty( $vendor_ids ) ) {
                    foreach ( $vendor_ids as $vendor_id ) {
                        $call_api = new EMV_Send_SMS( $vendor_id, '', 1 );
                        $send     = $call_api->send_phone_sms();
                        if ( $send ) {
                            ++ $send_count;
                        } else {
                            ++ $failed_count;
                        }
                    }
                } else {
                    wp_send_json( [
                        'message' => true,
                        'send'    => 0,
                        'failed'  => 0,
                    ] );
                }
                wp_send_json( [
                    'message' => false,
                    'send'    => $send_count,
                    'failed'  => $failed_count,
                ] );
            }
           die();
        }

    }
    new EMV_vendor_ajax();
}