<?php
if ( !defined('ABSPATH')) {
    exit;
}

/**
 * Helpear Method
 */
if ( ! class_exists( 'EMV_helper' ) ) {
    /**
     * Register helper class for store common use method
     * 
     * @version 1.0.0
     */
    class EMV_helper {
        /**
         * Object Calling Method
         * 
         * @verion 1.0.0
         */
        public function __construct( $author_id = 0, $user_phone = '',$shop_name="",$display_name="", $language = 'en_US' ) {
        
            $this->author_id        = $author_id;
            $this->vendor_phone     = $user_phone;
            $this->shopName         = $shop_name;
            $this->display_name     = $display_name;   
            $this->language         = $language;
        }
         /**
         * Check user role and capability.
         *
         * @return string
         */
        public function emv_can_vendor() {
            $capability = '';
        
            if ( function_exists( 'dokan' ) ) {
                $capability = 'dokandar';
            }
        
            if ( class_exists( 'WCFMmp' ) ) {
                $capability = 'wcfm_vendor';
            }
            return current_user_can( $capability );
        }
        
        /**
         * senitize all array value
         * 
         * @param $array
         * 
         * @return mixed
         */
        public function recursive_sanitize_text_field( $array ) {
        
            foreach ($array as $key => & $value ) {
            
                if ( is_array( $value ) ) {
                    $value = $this->recursive_sanitize_text_field( $value );
                } else {
                    $value = sanitize_text_field( $value );
                }
            }
        
            return $array;
        }


         /**
         * emv update Options method 
         * This function use for save setting data in option fields
         * 
         * @return void
         * @version 1.0.0
         */
        public function emv_update_option( $key, $value, $default = "" ) {
            if ( is_string( $default ) ) {
                $value = trim( $value, ' ' );
            } 
            $value = isset( $value ) && ! empty( $value ) ? $value : $default;
            $sanitize_value = sanitize_text_field( $value );

            update_option( "emv_$key", $sanitize_value );
        }
        /**
         * Get option value
         * 
         * @return single option value
         */
        public function get_option_values ( $optionName, $default = "", $API = false ) {
            
            if ( is_int( $default ) && $API == false  ) {
                $option_value = (bool) get_option ( "emv_{$optionName}",$default );
            } else {
                $option_value = get_option ( "emv_{$optionName}",$default );
            }
            return $option_value;
        }
        /**
         * Check security and permissions
         * 
         * @return boolean
         * @version 1.0.0
         */
        public function emv_check_security( $security, $nonce, $vendor = false ) {
            if  ( ! isset( $security) || ! wp_verify_nonce( $security, $nonce ) ) {
                wp_die ( -1, 403);
            }
            if ( ! $vendor ) {
                if ( ! current_user_can( 'manage_options') ) {
                    return false;
                }
            } else {
                if ( ! $this->emv_can_vendor() ) {
                    return false;
                }
            }
            if ( ! is_user_logged_in() ) {
                return false;
            }
            return true;
        }
    }
}

