<?php
/**
 * This file will create Custom Rest API End Points.
 * 
 * @version 1.0.0
 */
if ( ! class_exists( 'emv_register_rest_api' ) ) {
    /**
     * Register EMV end points
     * 
     * @version 1.0.0
     */
    class emv_register_rest_api {
        /**
         * Store Helper instance
         * Public @var
         * 
         * @version 1.0.0
         */
        public $emv_helper;
        /**
         * Calling method
         * 
         * @version 1.0.0
         */
        function __construct() {
            $this->emv_helper = new EMV_helper();
            add_action('rest_api_init', [$this, 'create_emv_rest_api_routes']);
        }
        /**
         * Register rest route for emv post.
         * @version 1.0.0
         * 
         * @return void
         */
        public function create_emv_rest_api_routes() {
            register_rest_route('easy_to_manage_vendor/v1', '/apiSetting', [
                'methods'             => 'POST',
                'callback'            => [ $this, 'save_emv_apiSetting' ],
                'permission_callback' => [ $this, 'check_emv_apiSetting_permission' ]
            ]);
            register_rest_route('easy_to_manage_vendor/v1', '/configaration', [
                'methods'             => 'POST',
                'callback'            => [ $this, 'save_emv_configaration' ],
                'permission_callback' => [ $this, 'check_emv_configaration_permission' ]
            ]);
            register_rest_route('easy_to_manage_vendor/v1', '/customMessage', [
                'methods'             => 'POST',
                'callback'            => [ $this, 'save_emv_customMessage' ],
                'permission_callback' => [ $this, 'check_emv_customMessage_permission' ]
            ]);
        }
        /**   
         * Save emv API Setting option data
         * 
         * @return json
         * @version 1.0.0
         */
        public function save_emv_apiSetting( $request ) {
            $this->emv_helper->emv_update_option( 'enable_automatic_sms', $request['enable_automatic_sms'], 0);
            $this->emv_helper->emv_update_option( 'enable_vendor_automatic_sms', $request['enable_vendor_automatic_sms'], 0 );
            $this->emv_helper->emv_update_option( 'select_api', $request['select_api'], 1 );
            $this->emv_helper->emv_update_option( 'ultramsg_instance_id', $request['ultramsg_instance_id'] );
            $this->emv_helper->emv_update_option( 'ultramsg_auth_token', $request['ultramsg_auth_token'] );
            $this->emv_helper->emv_update_option( 'twilio_account_sid', $request['twilio_account_sid'] );
            $this->emv_helper->emv_update_option( 'twilio_auth_token', $request['twilio_auth_token'] );
            $this->emv_helper->emv_update_option( 'twilio_sender_number', $request['twilio_sender_number'] );
            return rest_ensure_response('success');
        }
 
        /**
         * Save Configaration Setting option data
         * 
         * @return json 
         * @version 1.0.0
         */
        public function save_emv_configaration( $request ) {
            $this->emv_helper->emv_update_option( 'default_country_select', $request['default_country_select'], 0 );
            $this->emv_helper->emv_update_option( 'disable_vendor_chat', $request['disable_vendor_chat'], 0 );
            $this->emv_helper->emv_update_option( 'disable_vendor_number_Forcibly', $request['disable_vendor_number_Forcibly'], 0 );
            $this->emv_helper->emv_update_option( 'hide_phone_number', $request['hide_phone_number'], 0 );
            $this->emv_helper->emv_update_option( 'enable_edit_mode', $request['enable_edit_mode'], 0 );
            $this->emv_helper->emv_update_option( 'enable_api_edit_mode', $request['enable_api_edit_mode'], 0 );
            return rest_ensure_response('success');
        }
        /**
         * Save message default data 
         * 
         * @return json
         * @version 1.0.0
         */
        public function save_emv_customMessage( $request ) {
            $this->emv_helper->emv_update_option( 'message_subject', $request['message_subject'], 'Initial conversation' );
            $this->emv_helper->emv_update_option( 'message_desc', $request['message_desc'], 'Hello {vendorShopName}, how are you.' );
            return rest_ensure_response('success');
        }
        
        /**
        * Check user role and capabiltiy and save option value.
        * @param null
        *
        *@return boolean
        */
        public function check_emv_apiSetting_permission() {
          return $this->check_save_capabilities();
        }
        /**
        * Check user role and capabiltiy and save option value.
        * @param null
        *
        *@return boolean
        */
        public function check_emv_configaration_permission() {
            return $this->check_save_capabilities();
        }
        /**
        * Check user role and capabiltiy and save option value.
        * @param null
        *
        *@return boolean
        */
        public function check_emv_customMessage_permission() {
            return $this->check_save_capabilities();
        }
        /**
         * Check data save capabiltiy
         * 
         * @return boolean
         * @version 1.0.0
         */
        public function check_save_capabilities() {
            if ( ! current_user_can( 'manage_options' ) ) {
                return false;
            }
            
            if ( ! is_user_logged_in() ) {
                return false;
            }

            return true;
        }
        
    }
    new emv_register_rest_api();
}
