<?php
if ( !defined('ABSPATH') ) {
    exit;
}

/**
 * Sent Automatic SMS
 */

if ( ! class_exists( 'EMV_Send_SMS' ) ) {
    class EMV_Send_SMS {
        /**
         * Calling method
         *
         * @version 1.0.0
         */
        public function __construct( $vendor_id, $message, $bulk = 0 ) {
            $this->vendor_id       = $vendor_id;
            $this->phone_number = get_user_meta( $vendor_id, 'EMV_phone_number', true );
            if ( $bulk == 1 ) {
                $userInfo     = get_userdata( $vendor_id );
                $shop_name    = $userInfo->user_nicename;
                $from_name    = get_bloginfo( 'name' );
                $emv_sub      = get_option ( 'emv_message_subject' );
                $emv_sub1     = str_replace( '{vendorShopName}', $shop_name, $emv_sub );
                $emv_message  = get_option ( 'emv_message_desc' );
                $emv_message1 = str_replace( '{vendorShopName}', $shop_name, $emv_message );
                $messages     = "From : $from_name\r\nSubject : $emv_sub1 \r\nMessage: $emv_message1 ";
                $this->message = $messages;
            } else {
                $this->message = $message;
            }
        }
        public function send_phone_sms() {
            $w_Number = $this->phone_number;
            $messages = $this->message;
            $which_api_active   = get_option('emv_select_api');
            if ( $which_api_active == '2' ) {
                $sid            = get_option('emv_twilio_account_sid');
                $token          = get_option('emv_twilio_auth_token');
                $form           = get_option('emv_twilio_sender_number');
                $in_stock_urls  = "https://api.twilio.com/2010-04-01/Accounts/$sid/Messages.json";
                $data = array(
                    'To'   => "whatsapp:$w_Number",
                    'From' => "whatsapp:$form",
                    'Body' => $messages,
                );
               
                $headers = array(
                    'Authorization' => 'Basic ' . base64_encode($sid . ':' . $token)
                );

                $result = wp_remote_post($in_stock_urls, array(
                    'body' => $data,
                    'headers' => $headers
                ));
                if ( is_wp_error( $result ) ) {
                    do_action('emv_sms_sent_failure', $this->vendor_id, 0 );
                    return false;
                } else {
                    $response = json_decode(wp_remote_retrieve_body($result));
                    if ( is_object( $response ) ) {
                        $f_curl = $response->status;
                        if ($f_curl == 'queued') {
                            do_action('emv_sms_sent_success', $this->vendor_id, 1 );
                            return true;
                        } else {
                            do_action('emv_sms_sent_failure', $this->vendor_id, 0 );
                            return false;
                        }
                    } else {
                        do_action('emv_sms_sent_failure', $this->vendor_id, 0 );
                        return false;
                    }
                }
            } elseif ( $which_api_active == '1' ) {
                $ultaInstanceId   = get_option('emv_ultramsg_instance_id');
                $ultramsg_token   = get_option('emv_ultramsg_auth_token');

                $ultr_url = "https://api.ultramsg.com/$ultaInstanceId/messages/chat";
                $query = array(
                    'token'       =>  $ultramsg_token,
                    'to'          =>  $w_Number,
                    'body'        =>  $messages,
                    'priority'    => 1,
                    'referenceId' => 0  
                );
                $responses = wp_remote_post( $ultr_url, array(
                    'method' => 'POST',
                    'timeout' => 30,
                    'httpversion' => '1.0',
                    'headers' => array(
                        "content-type: application/x-www-form-urlencoded"
                    ),
                    'body' => $query,
                    'cookies' => array()
                    )
                );

                if ( is_wp_error( $responses ) ) {
                    do_action('emv_sms_sent_failure', $this->vendor_id, 0 );
                    return false;
                } else {
                    $decodes = json_decode(wp_remote_retrieve_body($responses),true);
                    if ( is_array($decodes) ) {
                      if ( array_key_exists('sent', $decodes ) ) {
                        if ( $decodes['sent'] == 'true' ) {
                            do_action('emv_sms_sent_success', $this->vendor_id, 1 );
                            return true;
                         }
                        } elseif (array_key_exists('error',$decodes) ) {
                            if ( $decodes['error'] ) { 
                                do_action('emv_sms_sent_failure', $this->vendor_id, 0 );
                                return false;
                            }
                        }
                    } else {
                        do_action('emv_sms_sent_failure', $this->vendor_id, 0 );
                        return false;
                    }
                }   
            }
        }
    }
}