
<?php
/**
 * Add Extra menu for vendor chat
 *
 * @package EMV
 */
// if direct access than exit the file.
defined( 'ABSPATH' ) || exit;
/**
 * Check class is already exists
 *
 * @version 1.0.0
 */
if ( ! class_exists( 'EMV_WCFM_Menu' ) ) {
    /**
     * Add Extra menu for vendor chat
     *
     * @package EMV
     */
    class EMV_WCFM_Menu {
		/**
		 * Calling method
		 *
		 * @return void
		 */
        public function __construct(){
            add_filter('wcfm_menus', [ $this, 'ws_get_wcfm_menus' ], 30, 1 );
            add_filter( 'wcfm_query_vars', [ $this, 'wcfmcsm_query_vars' ], 50 );
            add_filter( 'wcfm_endpoint_title', [ $this, 'wcfmcsm_endpoint_title' ], 50, 2 );
            add_filter( 'wcfm_endpoints_slug', [ $this, 'wcfm_custom_menus_endpoints_slug' ] );
            add_action( 'wcfm_load_views', [ $this, 'wcfm_csm_load_views' ], 50 );
            add_action( 'before_wcfm_load_views', [ $this, 'wcfm_csm_load_views' ], 50 );
            add_action( 'wcfm_page_heading', [ $this, 'emv_wcfm_member_header' ] );
            
        }
        /**
         * Show empty phone number popup
         *
         * @version 1.0.0
         */
        public function emv_wcfm_member_header() {
            do_action( 'emv_empty_phone_number_popup' );
        }
        /**
         *  WCFM - Custom Menus Views
         */
        public function wcfm_csm_load_views( $end_point ) {
            global $WCFM, $WCFMu;
            $plugin_path = trailingslashit( dirname( __FILE__  ) );
            switch( $end_point ) {
                case 'emv-chatting':
                    require_once( $plugin_path . 'views/emv-page.php' );
                break;
            }
        }
        /**
         * WCFM - Custom Menus Endpoiint Edit
         */
        function wcfm_custom_menus_endpoints_slug( $endpoints ) {
            
            $custom_menus_endpoints = [
                                    'emv-chatting' => 'emv-chatting',

            ];
            
            $endpoints = array_merge( $endpoints, $custom_menus_endpoints );
            
            return $endpoints;
        }
        /**
         * WCFM - Custom Menus End Point Title
         */
        function wcfmcsm_endpoint_title( $title, $endpoint ) {
            global $wp;
            switch ( $endpoint ) {
                case 'emv-chatting' :
                    $title = __( 'Chat with Admin', 'EMV' );
                break;
            }
            
            return $title;
        }

        /**
         * WCFM - Custom Menus Query Var
         */
        function wcfmcsm_query_vars( $query_vars ) {
            $wcfm_modified_endpoints = (array) get_option( 'wcfm_endpoints' );  
            $query_custom_menus_vars = array(
                'emv-chatting'              => ! empty( $wcfm_modified_endpoints['emv-chatting'] ) ? $wcfm_modified_endpoints['emv-chatting'] : 'emv-chatting',
            );
            $query_vars = array_merge( $query_vars, $query_custom_menus_vars );
            return $query_vars;
        }
        /**
         * Register WCFM Extra menu for vendor chatting list.
         *
         * @version 1.0.0
         */
        public function ws_get_wcfm_menus( $wcfm_menus ) {
            $helper = new EMV_helper();
            if ( $helper->emv_can_vendor() ) {
                $custom_menu = $wcfm_menus['emv-chatting'] = [
                    'label' => __( 'Chat with admin', 'EMV' ),
                    'url' => $this->get_wcfm_storepep_url( 'emv-chatting' ),
                    'icon' => 'comment-alt'
                ];
                $wcfm_menus = array_merge( $wcfm_menus, $custom_menu );
            }
            return $wcfm_menus;
        }

        public function get_wcfm_storepep_url($endpoint) {
            global $WCFM;
            $wcfm_page = get_wcfm_page();
            $get_wcfm_settings_url = wcfm_get_endpoint_url( $endpoint, '', $wcfm_page );
            return $get_wcfm_settings_url;
        }    
    }
    new EMV_WCFM_Menu();
} 