<?php

if ( ! defined('ABSPATH')) {
    die();
}

/**
 * EMV All Hook
 * 
 * @version 1.0.0
 */

 if ( ! class_exists('EMV_vendor_hook') ) {

    class EMV_vendor_hook {
        public function __construct() {
            add_action( 'emv_sms_sent_success', [ $this,'update_sms_sent_status' ], 10, 2 );
            add_action( 'emv_sms_sent_failure', [ $this,'sms_failed_status' ], 10, 2 );
            add_action( 'emv_chat_with_system_admin_form', [ $this, 'chat_wtih_system_admin_form' ], 10, 2 );
            $disable_Forcibly = get_option( 'emv_disable_vendor_number_Forcibly', 0 );
            if ( $disable_Forcibly != '1' ) {
                add_action( 'emv_empty_phone_number_popup', [ $this, 'emv_empty_number_popup'] ); 
            }
            add_action( 'wp_head', [ $this, 'emv_style' ] );
        }
        /**
         * Custom css
         *
         * @version 1.0.0
         */
        public function emv_style() {
            $custom_style = get_option( 'emv_custom_css' );
            ?>
            <style>
                <?php printf( $custom_style ); ?>
            </style>

            <?php
        }
        /**
         * Show poppu when whtsApp number is empty
         *
         * @version 1.0.0
         */
        public function emv_empty_number_popup() {
            $helper = new EMV_helper();
            if ( $helper->emv_can_vendor() ) {
                $current_user_id = get_current_user_id();
            } else {
                return false;
            }
            if ( ! is_user_logged_in() ) {
                return false;
            }
            $phone = get_user_meta( $current_user_id, 'EMV_phone_number', true );
            if ( empty( $phone ) && $phone == '' ) {
            ?>
            <div class="emv_phone_force_popup active" id="emv_phone_force_popup" >
                <div class="emv_content">
                    <div class="emv_phone_number_force">
                        <div class="EMV_sub_main">
                            <p class="form-row form-group form-row-wide emv_dokan_phone_setting">
                                <label for="EMV_phone_number" class="emv_dokan_label_setting"><?php esc_html_e( 'Enter your whatsApp number', 'EMV' ); ?><span class="required"></span></label>
                                <input type="hidden" name="emv_current_user_id" id="emv_current_user_id" class="emv_current_user_id" value=<?php echo esc_attr( $current_user_id ); ?>>
                                <input type="hidden" name="EMV_country_code" id="EMV_country_code" class="EMV_country_code" value="+1">
                                <input  type="tel" id="EMV_phone" name="EMV_phone_number" class="EMV_dokan_phone_sms" value="" required="required" >
                                <span id="EMV_valid_msg" class="hide"><?php _e('✓ Valid','EMV'); ?></span>
                                <span style="size:10px" id="EMV_error_msg" class="hide"></span>
                                <span class="emv_dokan_save"><?php _e('Save','EMV'); ?></span>
                            </p>
                        </div>      
                    </div>   
                </div>
            </div>
            <?php
            }
        }
        /**
         * Chat with system admin form
         *
         * @version 1.0.0
         */
        public function chat_wtih_system_admin_form( $wcfm_page, $value ) {
            $helper = new EMV_helper();
            if ( $helper->emv_can_vendor() ) {
                $current_user_id = get_current_user_id();
            } else {
                return false;
            }
            if ( ! is_user_logged_in() ) {
                return false;
            }
            $phone        = get_user_meta( $current_user_id, 'EMV_phone_number', true );
            $userInfo     = get_userdata( $current_user_id );
            $shop_name    = $userInfo->user_nicename;
            $display_name = $userInfo->display_name;
            $disable_Forcibly1 = get_option( 'emv_disable_vendor_number_Forcibly', 0 );
            
            ?>
            <div class="EMV_dokan_main <?php if ( $wcfm_page == 'wcfm' ): echo 'emv_wcfm_main';endif ?>">
                <fieldset>
                    <?php 
                        if ( $wcfm_page != 'wcfm'  ) :
                    ?>
                            <legend><?php _e( 'Chat with system admin via WhatsApp :','EMV'); ?></legend>
                    <?php 
                        endif;
                    ?>
                    <div class='EMV_dokan_section'>
                        <div class="EMV_sub_main">
                            <p class="EMV_admin_note"><?php _e('Note: Please enter your whatsApp number. The admin will connact you through this number.','EMV' ); ?></p>
                            <?php
                            if ( ! empty( $phone ) || $disable_Forcibly1 == '1' ) {
                                ?>
                                <p class="form-row form-group form-row-wide emv_dokan_phone_setting">
                                    <label for="EMV_phone_number" class="emv_dokan_label_setting"><?php esc_html_e( 'Change Number', 'EMV' ); ?><span class="required"></span></label>
                                    <input type="hidden" name="emv_current_user_id" id="emv_current_user_id" class="emv_current_user_id" value=<?php echo esc_attr( $current_user_id ); ?>>
                                    <input type="hidden" name="emv_shop_name" id="emv_shop_name" class="emv_shop_name" value=<?php echo esc_attr( $shop_name ); ?>>
                                    <input type="hidden" name="emv_display_name" id="emv_display_name" class="emv_display_name" value=<?php echo esc_attr( $display_name ); ?>>
                                    <input type="hidden" name="EMV_country_code" id="EMV_country_code" class="EMV_country_code" value="+1">
                                    <input  type="tel" id="EMV_phone" name="EMV_phone_number" class="EMV_dokan_phone_sms" value="<?php echo esc_attr( $phone );?>" required="required" >
                                    <span id="EMV_valid_msg" class="hide">✓ Valid</span>
                                    <span style="size:10px" id="EMV_error_msg" class="hide"></span>
                                    <span class="emv_dokan_save">Save</span>
                                </p>
                                <?php
                            }
                            ?>
                        </div> 
                        <!-- <div class="emv_dokan_setting_divider"></div>  -->
                        <div class="admin_phone_number_empty_message"></div>
                        <div class="EMV_live_Chat">
                            <div class="emv_chat_header">
                                <?php _e( 'Contact via WhatsApp', 'EMV' ); ?>
                            </div>
                            <div class="emv_dokan_content">
                                <input type="hidden" name="emv_current_user_id" id="emv_current_user_id" class="emv_current_user_id" value=<?php echo esc_attr( $current_user_id ); ?>>
                                <textarea id="emv_verndor_text" rows="7" name="emv_verndor_message" placeholder="Enter Message here"></textarea>
                                <a target="_blank" class="emv_dokan_send_button" id="emv_send_button">
                                    <?php _e( 'Send on WhatsApp','EMV'); ?>
                                </a>
                            </div>
                        </div>
                    </div>
                </fieldset>
            </div>   
            <?php
        }
        /**
         * Update sms send status
         */
        public function sms_failed_status( $vendor_id ,$hook ) {
            update_user_meta( $vendor_id, 'emv_user_sms_status', 'failed' );
         }

        /**
         * Update sms failed status
         */
        public function update_sms_sent_status( $vendor_id, $hook ) {
            update_user_meta( $vendor_id, 'emv_user_sms_status', 'send' );
        }
    
    }
    new EMV_vendor_hook();

 }